;
; RIOT RAM test
;
; Read the RIOT RAM at start up and output the results
; This was a request (sort of) made by Eckhard Stolberg on
; Thurs, Oct. 31, 2002 while responding to my
; Climber5 prototype...comments??? message
;
; NTSC and PAL settings are selectable by the right difficulty switch
; (A = PAL, B = NTSC)
;
; NTSC will display RAM from $80 - $E6
; PAL will display RAM from $80 - $F8
;
; This display is as...
; $80 $81 $82 $83 $84 $85
; $86 $86 $88 $89 $8A $8B...
;
; RAM locations $EE - $FD were use for the program. JSRs were avoided to
; avoid stack manipulation.
;
; Even though all variables are not being shown, it gives an idea of the
; RAM state at Stella power up. The idea is to run this on an EPROM so the
; suspected randomness can be witnessed.
;
; This has been tested with
; o Z26 (all RAM values 00 at start up)
; o CyberStella (RAM values not 00 at startup)
; o PCAE 2.2 (RAM values 00 at startup)
;
; The screen colors were to simulate an Atari 8-bit :)


;============================================================================
; C O N S T A N T S
;============================================================================
FONT_HEIGHT				=	$05
RAM_START				=	$80

NTSC_VBLANK_WAIT		=	$2B
NTSC_OVERSCAN_WAIT	=	$22
NTSC_NAVY				=	$90
NTSC_BLUE				=	$9B
NTSC_RAM_STOP			=	$E1

PAL_VBLANK_WAIT		=	$35
PAL_OVERSCAN_WAIT		=	$2A
PAL_NAVY					=	$D0
PAL_BLUE					=	$DD
PAL_RAM_STOP			=	$F3

	include vcs.h
	processor 6502

;============================================================================
; Z P - V A R I A B L E S
;============================================================================
	SEG.U vars
	.org $EE
ramPlaceHolder		ds	2
fontHeight			ds	1
hexValuePointers	ds	12
temp					ds	1

	SEG code
	.org $F000
Start
	cld

	lda #$00	
	ldx #$7f
.clearRAM
	sta VSYNC,x
	dex
	bpl .clearRAM
	
	txs										; set the stack to the beginning
	
VerticalSync
	lda #$02
	ldx #$00
	sta WSYNC
	sta VSYNC								; start new frame
	sta WSYNC								; first line for VSYNC
	sta WSYNC								; second line of VSYNC
	sta WSYNC								; third and final line of VSYNC
	stx VSYNC								; end vertical sync
	
	bit SWCHB
	bmi .setPALValues
	
	lda #NTSC_VBLANK_WAIT
	sta TIM64T
	
	lda #NTSC_NAVY
	sta COLUBK
	
	lda #NTSC_BLUE
	sta COLUP0
	sta COLUP1
	jmp SetupPlayers

.setPALValues
	lda #PAL_VBLANK_WAIT
	sta TIM64T

	lda #PAL_NAVY
	sta COLUBK
	
	lda #PAL_BLUE
   sta COLUP0
   sta COLUP1
	
SetupPlayers
	lda #RAM_START
	sta ramPlaceHolder+1

;
; setting up for a six digit display centered on the screen
;
	lda #$03									; 3 copies of GRP0 and GRP1 close
	sta NUSIZ0
	sta NUSIZ1
	
;
; move the players to the center of the screen
;
	ldx #$06									; move the players 12 columns over
	ldy #$00
	sta ramPlaceHolder					; 0 for page zero indirect indexing
	sta WSYNC
.movePlayerLoop
	dex
	bpl .movePlayerLoop
	nop
	sta RESP0
	sta RESP1
	lda #%11010000							; move player 0 right 3 pixels
	sta HMP0
	lda #%11100000							; move player 1 right 2 pixels
	sta HMP1
	sta WSYNC
	sta HMOVE
.vblankwait
	lda INTIM
	bne .vblankwait
	
	sta WSYNC
	sta VBLANK
	sta HMCLR
	sta WSYNC
	
	bit SWCHB
	bpl DisplayKernel

;
; 2 extra scan lines for PAL
;
	sta WSYNC
	sta WSYNC
	
DisplayKernel
	lda #FONT_HEIGHT
	sta fontHeight
	
	lda #$00
	sta GRP0
	sta GRP1
	sta VDELP0
	sta VDELP1
	ldy #FONT_HEIGHT
	ldx #$0A
.hexValueLoop
	lda (ramPlaceHolder+1),y
	asl
	asl
	asl	
	clc
	adc #<HexNumbers
	sta hexValuePointers,x
	lda (ramPlaceHolder+1),y
	and #$F0									; mask the lower nibbles
	lsr										; shift the upper nibbles to the
	lsr										; lower nibbles
	lsr
	lsr
	lsr										; divide by 2
	clc
	adc #>HexNumbers						; add the value to HexNumbers upper bits
	sta hexValuePointers+1,x			; to get the font starting position
	dex
	dex
	dey
	bpl .hexValueLoop
	
;
; typical 6 digit display
;
	lda #$01
	sta VDELP0
	sta VDELP1
.drawRAMValues
	ldy fontHeight
	lda (hexValuePointers),y
	sta GRP0
	sta WSYNC
	lda (hexValuePointers+2),y
	sta GRP1
	lda (hexValuePointers+4),y
	sta GRP0
	lda (hexValuePointers+6),y
	sta temp
	lda (hexValuePointers+8),y
	tax
	lda (hexValuePointers+10),y
	tay
	lda temp
	sta GRP1
	stx GRP0
	sty GRP1
	sta GRP0
	dec fontHeight
	bpl .drawRAMValues

;
; increment the RAM place holder for the next read
;
	lda ramPlaceHolder+1
	clc
	adc #$06
	sta ramPlaceHolder+1
	bit SWCHB
	bmi .palCompare
	cmp #NTSC_RAM_STOP
	bcc DisplayKernel
	jmp FinishDisplayKernel
	
.palCompare
	cmp #PAL_RAM_STOP
	bcc DisplayKernel
	
FinishDisplayKernel
	lda #$00
	sta GRP0
	sta GRP1
	sta VDELP0
	sta VDELP1
	lda #$02
	sta WSYNC
	sta WSYNC
	sta WSYNC
	sta WSYNC
	sta WSYNC
	sta WSYNC
	sta VBLANK
	
	lda #NTSC_OVERSCAN_WAIT
	bit SWCHB
	bpl .setOverscanWait
	lda #PAL_OVERSCAN_WAIT
.setOverscanWait
	sta TIM64T
.overscanLoop
	lda INTIM
	bne .overscanLoop
	jmp VerticalSync
	
;
; hex fonts start a new page to avoid crossing page boundaries
; also the values are padded with 2 zeroes to make sure the
; values don't cross. The hex number fonts take up ~2K!!!
;
   .org $F700
HexNumbers
	.byte $00,$44,$AA,$AA,$AA,$44,$00,$00
	.byte $00,$44,$A4,$A4,$A4,$44,$00,$00
	.byte $00,$4E,$A8,$AC,$A2,$4C,$00,$00
	.byte $00,$4C,$A2,$AE,$A2,$4C,$00,$00
	.byte $00,$42,$A2,$AE,$AA,$4A,$00,$00
	.byte $00,$4C,$A2,$AC,$A8,$4E,$00,$00
	.byte $00,$44,$AA,$AC,$A8,$46,$00,$00
	.byte $00,$44,$A4,$A4,$A2,$4E,$00,$00
	.byte $00,$44,$AA,$A4,$AA,$44,$00,$00
	.byte $00,$4C,$A2,$A6,$AA,$44,$00,$00
	.byte $00,$4A,$AA,$AE,$AA,$44,$00,$00
	.byte $00,$4E,$AA,$AC,$AA,$4E,$00,$00
	.byte $00,$44,$AA,$A8,$AA,$44,$00,$00
	.byte $00,$4C,$AA,$AA,$AA,$4C,$00,$00
	.byte $00,$4E,$A8,$AE,$A8,$4E,$00,$00
	.byte $00,$48,$A8,$AE,$A8,$4E,$00,$00

	.byte $00,$44,$4A,$4A,$4A,$44,$00,$00
	.byte $00,$44,$44,$44,$44,$44,$00,$00
	.byte $00,$4E,$48,$4C,$42,$4C,$00,$00
	.byte $00,$4C,$42,$4E,$42,$4C,$00,$00
	.byte $00,$42,$42,$4E,$4A,$4A,$00,$00
	.byte $00,$4C,$42,$4C,$48,$4E,$00,$00
	.byte $00,$44,$4A,$4C,$48,$46,$00,$00
	.byte $00,$44,$44,$44,$42,$4E,$00,$00
	.byte $00,$44,$4A,$44,$4A,$44,$00,$00
	.byte $00,$4C,$42,$46,$4A,$44,$00,$00
	.byte $00,$4A,$4A,$4E,$4A,$44,$00,$00
	.byte $00,$4E,$4A,$4C,$4A,$4E,$00,$00
	.byte $00,$44,$4A,$48,$4A,$44,$00,$00
	.byte $00,$4C,$4A,$4A,$4A,$4C,$00,$00
	.byte $00,$4E,$48,$4E,$48,$4E,$00,$00
	.byte $00,$48,$48,$4E,$48,$4E,$00,$00

	.byte $00,$E4,$8A,$CA,$2A,$C4,$00,$00
	.byte $00,$E4,$84,$C4,$24,$C4,$00,$00
	.byte $00,$EE,$88,$CC,$22,$CC,$00,$00
	.byte $00,$EC,$82,$CE,$22,$CC,$00,$00
	.byte $00,$E2,$82,$CE,$2A,$CA,$00,$00
	.byte $00,$EC,$82,$CC,$28,$CE,$00,$00
	.byte $00,$E4,$8A,$CC,$28,$C6,$00,$00
	.byte $00,$E4,$84,$C4,$22,$CE,$00,$00
	.byte $00,$E4,$8A,$C4,$2A,$C4,$00,$00
	.byte $00,$EC,$82,$C6,$2A,$C4,$00,$00
	.byte $00,$EA,$8A,$CE,$2A,$C4,$00,$00
	.byte $00,$EE,$8A,$CC,$2A,$CE,$00,$00
	.byte $00,$E4,$8A,$C8,$2A,$C4,$00,$00
	.byte $00,$EC,$8A,$CA,$2A,$CC,$00,$00
	.byte $00,$EE,$88,$CE,$28,$CE,$00,$00
	.byte $00,$E8,$88,$CE,$28,$CE,$00,$00
   
	.byte $00,$C4,$2A,$EA,$2A,$C4,$00,$00
   .byte $00,$C4,$24,$E4,$24,$C4,$00,$00
	.byte $00,$CE,$28,$EC,$22,$CC,$00,$00
	.byte $00,$CC,$22,$EE,$22,$CC,$00,$00
	.byte $00,$C2,$22,$EE,$2A,$CA,$00,$00
	.byte $00,$CC,$22,$EC,$28,$CE,$00,$00
	.byte $00,$C4,$2A,$EC,$28,$C6,$00,$00
	.byte $00,$C4,$24,$E4,$22,$CE,$00,$00
	.byte $00,$C4,$2A,$E4,$2A,$C4,$00,$00
	.byte $00,$CC,$22,$E6,$2A,$C4,$00,$00
	.byte $00,$CA,$2A,$EE,$2A,$C4,$00,$00
	.byte $00,$CE,$2A,$EC,$2A,$CE,$00,$00
	.byte $00,$C4,$2A,$E8,$2A,$C4,$00,$00
	.byte $00,$CC,$2A,$EA,$2A,$CC,$00,$00
	.byte $00,$CE,$28,$EE,$28,$CE,$00,$00
	.byte $00,$C8,$28,$EE,$28,$CE,$00,$00
   
	.byte $00,$24,$2A,$EA,$AA,$A4,$00,$00
	.byte $00,$24,$24,$E4,$A4,$A4,$00,$00
	.byte $00,$2E,$28,$EC,$A2,$AC,$00,$00
	.byte $00,$2C,$22,$EE,$A2,$AC,$00,$00
	.byte $00,$22,$22,$EE,$AA,$AA,$00,$00
	.byte $00,$2C,$22,$EC,$A8,$AE,$00,$00
	.byte $00,$24,$2A,$EC,$A8,$A6,$00,$00
	.byte $00,$24,$24,$E4,$A2,$AE,$00,$00
	.byte $00,$24,$2A,$E4,$AA,$A4,$00,$00
	.byte $00,$2C,$22,$E6,$AA,$A4,$00,$00
	.byte $00,$2A,$2A,$EE,$AA,$A4,$00,$00
	.byte $00,$2E,$2A,$EC,$AA,$AE,$00,$00
	.byte $00,$24,$2A,$E8,$AA,$A4,$00,$00
	.byte $00,$2C,$2A,$EA,$AA,$AC,$00,$00
	.byte $00,$2E,$28,$EE,$A8,$AE,$00,$00
	.byte $00,$28,$28,$EE,$A8,$AE,$00,$00
   
	.byte $00,$C4,$2A,$CA,$8A,$E4,$00,$00
	.byte $00,$C4,$24,$C4,$84,$E4,$00,$00
	.byte $00,$CC,$22,$CC,$88,$EE,$00,$00
	.byte $00,$CC,$22,$CE,$82,$EC,$00,$00
	.byte $00,$C2,$22,$CE,$8A,$EA,$00,$00
	.byte $00,$CC,$22,$CC,$88,$EE,$00,$00
	.byte $00,$C4,$2A,$CC,$88,$E6,$00,$00
	.byte $00,$C4,$24,$C4,$82,$EE,$00,$00
	.byte $00,$C4,$2A,$C4,$8A,$E4,$00,$00
	.byte $00,$CC,$22,$C6,$8A,$E4,$00,$00
	.byte $00,$CA,$2A,$CE,$8A,$E4,$00,$00
	.byte $00,$CE,$2A,$CC,$8A,$EE,$00,$00
	.byte $00,$C4,$2A,$C8,$8A,$E4,$00,$00
	.byte $00,$CC,$2A,$CA,$8A,$EC,$00,$00
	.byte $00,$CE,$28,$CE,$88,$EE,$00,$00
	.byte $00,$C8,$28,$CE,$88,$EE,$00,$00

	.byte $00,$44,$AA,$CA,$8A,$64,$00,$00
	.byte $00,$44,$A4,$C4,$84,$64,$00,$00
	.byte $00,$4E,$A8,$CC,$82,$6C,$00,$00
	.byte $00,$4C,$A2,$CE,$82,$6C,$00,$00
	.byte $00,$42,$A2,$CE,$8A,$6A,$00,$00
	.byte $00,$4C,$A2,$CC,$88,$6E,$00,$00
	.byte $00,$44,$AA,$CC,$88,$66,$00,$00
	.byte $00,$44,$A4,$C4,$82,$6E,$00,$00
	.byte $00,$44,$AA,$C4,$8A,$64,$00,$00
	.byte $00,$4C,$A2,$C6,$8A,$64,$00,$00
	.byte $00,$4A,$AA,$CE,$8A,$64,$00,$00
	.byte $00,$4E,$AA,$CC,$8A,$6E,$00,$00
	.byte $00,$44,$AA,$C8,$8A,$64,$00,$00
	.byte $00,$4C,$AA,$CA,$8A,$6C,$00,$00
	.byte $00,$4E,$A8,$CE,$88,$6E,$00,$00
	.byte $00,$48,$A8,$CE,$88,$6E,$00,$00
	
	.byte $00,$44,$4A,$4A,$2A,$E4,$00,$00
	.byte $00,$44,$44,$44,$24,$E4,$00,$00
	.byte $00,$4E,$48,$4C,$22,$EC,$00,$00
	.byte $00,$4C,$42,$4E,$22,$EC,$00,$00
	.byte $00,$42,$42,$4E,$2A,$EA,$00,$00
	.byte $00,$4C,$42,$4C,$28,$EE,$00,$00
	.byte $00,$44,$4A,$4C,$28,$E6,$00,$00
	.byte $00,$44,$44,$44,$22,$EE,$00,$00
	.byte $00,$44,$4A,$44,$2A,$E4,$00,$00
	.byte $00,$4C,$42,$46,$2A,$E4,$00,$00
	.byte $00,$4A,$4A,$4E,$2A,$E4,$00,$00
	.byte $00,$4E,$4A,$4C,$2A,$EE,$00,$00
	.byte $00,$44,$4A,$48,$2A,$E4,$00,$00
	.byte $00,$4C,$4A,$4A,$2A,$EC,$00,$00
	.byte $00,$4E,$48,$4E,$28,$EE,$00,$00
	.byte $00,$48,$48,$4E,$28,$EE,$00,$00
   
	.byte $00,$44,$AA,$4A,$AA,$44,$00,$00
   .byte $00,$44,$A4,$44,$A4,$44,$00,$00
	.byte $00,$4E,$A8,$4C,$A2,$4C,$00,$00
	.byte $00,$4C,$A2,$4E,$A2,$4C,$00,$00
	.byte $00,$42,$A2,$4E,$AA,$4A,$00,$00
	.byte $00,$4C,$A2,$4C,$A8,$4E,$00,$00
	.byte $00,$44,$AA,$4C,$A8,$46,$00,$00
	.byte $00,$44,$A4,$44,$A2,$4E,$00,$00
	.byte $00,$44,$AA,$44,$AA,$44,$00,$00
	.byte $00,$4C,$A2,$46,$AA,$44,$00,$00
	.byte $00,$4A,$AA,$4E,$AA,$44,$00,$00
	.byte $00,$4E,$AA,$4C,$AA,$4E,$00,$00
	.byte $00,$44,$AA,$48,$AA,$44,$00,$00
	.byte $00,$4C,$AA,$4A,$AA,$4C,$00,$00
	.byte $00,$4E,$A8,$4E,$A8,$4E,$00,$00
	.byte $00,$48,$A8,$4E,$A8,$4E,$00,$00
	
	.byte $00,$C4,$2A,$6A,$AA,$44,$00,$00
	.byte $00,$C4,$24,$64,$A4,$44,$00,$00
	.byte $00,$CE,$28,$6C,$A2,$4C,$00,$00
	.byte $00,$CC,$22,$6E,$A2,$4C,$00,$00
	.byte $00,$C2,$22,$6E,$AA,$4A,$00,$00
	.byte $00,$CC,$22,$6C,$A8,$4E,$00,$00
	.byte $00,$C4,$2A,$6C,$A8,$46,$00,$00
	.byte $00,$C4,$24,$64,$A2,$4E,$00,$00
	.byte $00,$C4,$2A,$64,$AA,$44,$00,$00
	.byte $00,$CC,$22,$66,$AA,$44,$00,$00
	.byte $00,$CA,$2A,$6E,$AA,$44,$00,$00
	.byte $00,$CE,$2A,$6C,$AA,$4E,$00,$00
	.byte $00,$C4,$2A,$68,$AA,$44,$00,$00
	.byte $00,$CC,$2A,$6A,$AA,$4C,$00,$00
	.byte $00,$CE,$28,$6E,$A8,$4E,$00,$00
	.byte $00,$C8,$28,$6E,$A8,$4E,$00,$00

	.byte $00,$A4,$A8,$E8,$A8,$44,$00,$00
	.byte $00,$A4,$A4,$E4,$A4,$44,$00,$00
	.byte $00,$AE,$A8,$EC,$A2,$4C,$00,$00
	.byte $00,$AC,$A2,$EE,$A2,$4C,$00,$00
	.byte $00,$A2,$A2,$EE,$AA,$4A,$00,$00
	.byte $00,$AC,$A2,$EC,$A8,$4E,$00,$00
	.byte $00,$A4,$AA,$EC,$A8,$46,$00,$00
	.byte $00,$A4,$A4,$E4,$A2,$4E,$00,$00
	.byte $00,$A4,$AA,$E4,$AA,$44,$00,$00
	.byte $00,$AC,$A2,$E6,$AA,$44,$00,$00
	.byte $00,$AA,$AA,$EE,$AA,$44,$00,$00
	.byte $00,$AE,$AA,$EC,$AA,$4E,$00,$00
	.byte $00,$A4,$AA,$E8,$AA,$44,$00,$00
	.byte $00,$AC,$AA,$EA,$AA,$4C,$00,$00
	.byte $00,$AE,$A8,$EE,$A8,$4E,$00,$00
	.byte $00,$A8,$A8,$EE,$A8,$4E,$00,$00

	.byte $00,$E4,$A8,$C8,$A8,$E4,$00,$00
	.byte $00,$E4,$A4,$C4,$A4,$E4,$00,$00
	.byte $00,$EE,$A8,$CC,$A2,$EC,$00,$00
	.byte $00,$EC,$A2,$CE,$A2,$EC,$00,$00
	.byte $00,$E2,$A2,$CE,$AA,$EA,$00,$00
	.byte $00,$EC,$A2,$CC,$A8,$EE,$00,$00
	.byte $00,$E4,$AA,$CC,$A8,$E6,$00,$00
	.byte $00,$E4,$A4,$C4,$A2,$EE,$00,$00
	.byte $00,$E4,$AA,$C4,$AA,$E4,$00,$00
	.byte $00,$EC,$A2,$C6,$AA,$E4,$00,$00
	.byte $00,$EA,$AA,$CE,$AA,$E4,$00,$00
	.byte $00,$EE,$AA,$CC,$AA,$EE,$00,$00
	.byte $00,$E4,$AA,$C8,$AA,$E4,$00,$00
	.byte $00,$EC,$AA,$CA,$AA,$EC,$00,$00
	.byte $00,$EE,$A8,$CE,$A8,$EE,$00,$00
	.byte $00,$E8,$A8,$CE,$A8,$EE,$00,$00

	.byte $00,$44,$A8,$88,$A8,$44,$00,$00
	.byte $00,$44,$A4,$84,$A4,$44,$00,$00
	.byte $00,$4E,$A8,$8C,$A2,$4C,$00,$00
	.byte $00,$4C,$A2,$8E,$A2,$4C,$00,$00
	.byte $00,$42,$A2,$8E,$AA,$4A,$00,$00
	.byte $00,$4C,$A2,$8C,$A8,$4E,$00,$00
	.byte $00,$44,$AA,$8C,$A8,$46,$00,$00
	.byte $00,$44,$A4,$84,$A2,$4E,$00,$00
	.byte $00,$44,$AA,$84,$AA,$44,$00,$00
	.byte $00,$4C,$A2,$86,$AA,$44,$00,$00
	.byte $00,$4A,$AA,$8E,$AA,$44,$00,$00
	.byte $00,$4E,$AA,$8C,$AA,$4E,$00,$00
	.byte $00,$44,$AA,$88,$AA,$44,$00,$00
	.byte $00,$4C,$AA,$8A,$AA,$4C,$00,$00
	.byte $00,$4E,$A8,$8E,$A8,$4E,$00,$00
	.byte $00,$48,$A8,$8E,$A8,$4E,$00,$00
	
	.byte $00,$C4,$A8,$A8,$A8,$C4,$00,$00
	.byte $00,$C4,$A4,$A4,$A4,$C4,$00,$00
	.byte $00,$CE,$A8,$AC,$A2,$CC,$00,$00
	.byte $00,$CC,$A2,$AE,$A2,$CC,$00,$00
	.byte $00,$C2,$A2,$AE,$AA,$CA,$00,$00
	.byte $00,$CC,$A2,$AC,$A8,$CE,$00,$00
	.byte $00,$C4,$AA,$AC,$A8,$C6,$00,$00
	.byte $00,$44,$A4,$A4,$A2,$CE,$00,$00
	.byte $00,$44,$AA,$A4,$AA,$C4,$00,$00
	.byte $00,$4C,$A2,$A6,$AA,$C4,$00,$00
	.byte $00,$4A,$AA,$AE,$AA,$C4,$00,$00
	.byte $00,$4E,$AA,$AC,$AA,$CE,$00,$00
	.byte $00,$44,$AA,$A8,$AA,$C4,$00,$00
	.byte $00,$4C,$AA,$AA,$AA,$CC,$00,$00
	.byte $00,$4E,$A8,$AE,$A8,$CE,$00,$00
	.byte $00,$48,$A8,$AE,$A8,$CE,$00,$00
	
	.byte $00,$E4,$88,$E8,$88,$E4,$00,$00
	.byte $00,$E4,$84,$E4,$84,$E4,$00,$00
	.byte $00,$EE,$88,$EC,$82,$EC,$00,$00
	.byte $00,$EC,$82,$EE,$82,$EC,$00,$00
	.byte $00,$E2,$82,$EE,$8A,$EA,$00,$00
	.byte $00,$EC,$82,$EC,$88,$EE,$00,$00
	.byte $00,$E4,$8A,$EC,$88,$E6,$00,$00
	.byte $00,$E4,$84,$E4,$82,$EE,$00,$00
	.byte $00,$E4,$8A,$E4,$8A,$E4,$00,$00
	.byte $00,$EC,$82,$E6,$8A,$E4,$00,$00
	.byte $00,$EA,$8A,$EE,$8A,$E4,$00,$00
	.byte $00,$EE,$8A,$EC,$8A,$EE,$00,$00
	.byte $00,$E4,$8A,$E8,$8A,$E4,$00,$00
	.byte $00,$EC,$8A,$EA,$8A,$EC,$00,$00
	.byte $00,$EE,$88,$EE,$88,$EE,$00,$00
	.byte $00,$E8,$88,$EE,$88,$EE,$00,$00
	
	.byte $00,$84,$88,$E8,$88,$E4,$00,$00
	.byte $00,$84,$84,$E4,$84,$E4,$00,$00
	.byte $00,$8E,$88,$EC,$82,$EC,$00,$00
	.byte $00,$8C,$82,$EE,$82,$EC,$00,$00
	.byte $00,$82,$82,$EE,$8A,$EA,$00,$00
	.byte $00,$8C,$82,$EC,$88,$EE,$00,$00
	.byte $00,$84,$8A,$EC,$88,$E6,$00,$00
	.byte $00,$84,$84,$E4,$82,$EE,$00,$00
	.byte $00,$84,$8A,$E4,$8A,$E4,$00,$00
	.byte $00,$8C,$82,$E6,$8A,$E4,$00,$00
	.byte $00,$8A,$8A,$EE,$8A,$E4,$00,$00
	.byte $00,$8E,$8A,$EC,$8A,$EE,$00,$00
	.byte $00,$84,$8A,$E8,$8A,$E4,$00,$00
	.byte $00,$8C,$8A,$EA,$8A,$EC,$00,$00
	.byte $00,$8E,$88,$EE,$88,$EE,$00,$00
	.byte $00,$88,$88,$EE,$88,$EE,$00,$00

   .org $FFFC
   .word Start
   .word Start